@@ -11,20 +11,21 @@ class NotebookHandler(CodeHandler):
         filename (str) : a path to a Jupyter notebook (".ipynb") file
 
     """
-    
+
     _logger_text = "%s: call to %s() ignored when running notebooks with the 'bokeh' command."
 
     _origin = "Notebook"
 
     def __init__(self, *args, **kwargs):
-        
+
         nbformat = import_required('nbformat', 'The Bokeh notebook application handler requires Jupyter Notebook to be installed.')
         nbconvert = import_required('nbconvert', 'The Bokeh notebook application handler requires Jupyter Notebook to be installed.')
-        
+
         if 'filename' not in kwargs:
             raise ValueError('Must pass a filename to NotebookHandler')
+        filename = kwargs['filename']
 
-        with open(kwargs['filename']) as f:
+        with open(filename) as f:
             nb = nbformat.read(f, nbformat.NO_CONVERT)
             exporter = nbconvert.PythonExporter()
             source, meta = exporter.from_notebook_node(nb)
