@@ -3,15 +3,45 @@
 """
 from __future__ import absolute_import
 
-from ...properties import abstract
-from ...properties import Bool, Int, String, Enum, Instance, List, Tuple
-from ...enums import ButtonType
+import warnings
+
+from ...core.properties import abstract, HasProps
+from ...core.properties import Bool, Int, String, Enum, Instance, List, Tuple, Override
+from ...core.enums import ButtonType
 from ..callbacks import Callback
-from ..widget import Widget
+from .widget import Widget
 from .icons import AbstractIcon
 
 @abstract
-class AbstractButton(Widget):
+class ButtonLike(HasProps):
+    """ Shared properties for button-like widgets. """
+
+    button_type = Enum(ButtonType, help="""
+    A style for the button, signifying it's role.
+    """)
+
+    @property
+    def type(self):
+        warnings.warn(
+            """
+            Property 'type' was deprecated in Bokeh 0.12.0
+            and will be removed. Use 'button_type' instead.
+            """)
+        return self.button_type
+
+    @type.setter
+    def type(self, type):
+        warnings.warn(
+            """
+            Property 'type' was deprecated in Bokeh 0.12.0
+            and will be removed. Use 'button_type' instead.
+            """)
+        self.button_type = type
+
+    __deprecated_attributes__ = ('type',)
+
+@abstract
+class AbstractButton(Widget, ButtonLike):
     """ A base class that defines common properties for all
     button types. ``AbstractButton`` is not generally useful to
     instantiate on its own.
@@ -26,14 +56,11 @@ class AbstractButton(Widget):
     An optional image appearing to the left of button's text.
     """)
 
-    type = Enum(ButtonType, help="""
-    A style for the button, signifying it's role.
-    """)
-
     callback = Instance(Callback, help="""
     A callback to run in the browser whenever the button is activated.
     """)
 
+
 class Button(AbstractButton):
     """ A click button.
 
@@ -53,13 +80,16 @@ class Button(AbstractButton):
             None
 
         """
-        self.on_change('clicks', lambda obj, attr, old, new: handler())
+        self.on_change('clicks', lambda attr, old, new: handler())
+
 
 class Toggle(AbstractButton):
     """ A two-state toggle button.
 
     """
 
+    label = Override(default="Toggle")
+
     active = Bool(False, help="""
     The initial state of a button. Also used to trigger ``on_click`` event
     handler.
@@ -75,13 +105,15 @@ class Toggle(AbstractButton):
             None
 
         """
-        self.on_change('active', lambda obj, attr, old, new: handler(new))
+        self.on_change('active', lambda attr, old, new: handler(new))
 
 class Dropdown(AbstractButton):
     """ A dropdown button.
 
     """
 
+    label = Override(default="Dropdown")
+
     value = String(help="""
     A private property used to trigger ``on_click`` event handler.
     """)
@@ -105,7 +137,4 @@ class Dropdown(AbstractButton):
             None
 
         """
-        self.on_change('value', lambda obj, attr, old, new: handler(new))
-
-
-
+        self.on_change('value', lambda attr, old, new: handler(new))
