@@ -12,6 +12,8 @@ from tornado.httpserver import HTTPServer
 
 from .tornado import BokehTornado
 
+from bokeh import __version__
+
 from bokeh.application import Application
 
 from bokeh.resources import DEFAULT_SERVER_PORT
@@ -22,6 +24,15 @@ def _create_hosts_whitelist(host_list, port):
 
     hosts = []
     for host in host_list:
+        if '*' in host:
+            log.warning('Host wildcard %r can expose the application to HTTP '
+                        'host header attacks. Host wildcard should only be '
+                        'used for testing purpose.', host)
+        if host == '*':
+            # do not append the :80 port suffix in that case: any port is
+            # accepted
+            hosts.append(host)
+            continue
         parts = host.split(':')
         if len(parts) == 1:
             if parts[0] == "":
@@ -47,9 +58,14 @@ class Server(object):
             mapping from URL paths to Application instances, or a single Application to put at the root URL
             The Application is a factory for Document, with a new Document initialized for each Session.
             Each application should be identified by a path meant to go in a URL, like "/" or "/foo"
+    Kwargs:
+        num_procs (str):
+            Number of worker processes for an app. Default to one. Using 0 will autodetect number of cores
     '''
 
     def __init__(self, applications, **kwargs):
+        log.info("Starting Bokeh server version %s" % __version__)
+
         if isinstance(applications, Application):
             self._applications = { '/' : applications }
         else:
@@ -81,18 +97,28 @@ class Server(object):
 
         tornado_kwargs['hosts'] = _create_hosts_whitelist(kwargs.get('host', None), self._port)
         tornado_kwargs['extra_websocket_origins'] = _create_hosts_whitelist(kwargs.get('allow_websocket_origin', None), self._port)
+        tornado_kwargs['use_index'] = kwargs.get('use_index', True)
+        tornado_kwargs['redirect_root'] = kwargs.get('redirect_root', True)
 
         self._tornado = BokehTornado(self._applications, self.prefix, **tornado_kwargs)
         self._http = HTTPServer(self._tornado, xheaders=kwargs.get('use_xheaders', False))
         self._address = None
+
         if 'address' in kwargs:
             self._address = kwargs['address']
 
+        self._num_procs = kwargs.get('num_procs', 1)
+        if self._num_procs != 1:
+            assert all(app.safe_to_fork for app in self._applications.values()), (
+                      'User code has ran before attempting to run multiple '
+                      'processes. This is considered an unsafe operation.')
+
         # these queue a callback on the ioloop rather than
         # doing the operation immediately (I think - havocp)
         try:
             self._http.bind(self._port, address=self._address)
-            self._http.start(1)
+            self._http.start(self._num_procs)
+            self._tornado.initialize(**tornado_kwargs)
         except OSError as e:
             import errno
             if e.errno == errno.EADDRINUSE:
@@ -192,4 +218,3 @@ class Server(object):
         from bokeh.util.browser import view
         url = "http://localhost:%d%s%s" % (self.port, self.prefix, app_path)
         view(url, browser=browser, new=new)
-
