@@ -1,4 +1,4 @@
-var GuideRenderer, Renderer, _,
+var GuideRenderer, Renderer, _, p,
   extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
   hasProp = {}.hasOwnProperty;
 
@@ -6,6 +6,8 @@ _ = require("underscore");
 
 Renderer = require("./renderer");
 
+p = require("../../core/properties");
+
 GuideRenderer = (function(superClass) {
   extend(GuideRenderer, superClass);
 
@@ -15,16 +17,17 @@ GuideRenderer = (function(superClass) {
 
   GuideRenderer.prototype.type = 'GuideRenderer';
 
-  GuideRenderer.prototype.defaults = function() {
-    return _.extend({}, GuideRenderer.__super__.defaults.call(this), {
-      plot: null,
-      level: "overlay"
-    });
-  };
+  GuideRenderer.define({
+    plot: [p.Instance]
+  });
+
+  GuideRenderer.override({
+    level: 'overlay'
+  });
 
   return GuideRenderer;
 
-})(Renderer);
+})(Renderer.Model);
 
 module.exports = {
   Model: GuideRenderer
