@@ -86,6 +86,22 @@ ColumnDataSource = (function(superClass) {
     return this.trigger('stream');
   };
 
+  ColumnDataSource.prototype.patch = function(patches) {
+    var data, i, ind, j, k, patch, ref, ref1, value;
+    data = this.get('data');
+    for (k in patches) {
+      patch = patches[k];
+      for (i = j = 0, ref = patch.length; 0 <= ref ? j < ref : j > ref; i = 0 <= ref ? ++j : --j) {
+        ref1 = patch[i], ind = ref1[0], value = ref1[1];
+        data[k][ind] = value;
+      }
+    }
+    this.set('data', data, {
+      silent: true
+    });
+    return this.trigger('patch');
+  };
+
   return ColumnDataSource;
 
 })(DataSource.Model);
