@@ -328,6 +328,36 @@ class TestDocument(unittest.TestCase):
         assert len(curdoc_from_listener) == 1
         assert curdoc_from_listener[0] is d
 
+    def test_patch_notification(self):
+        d = document.Document()
+        assert not d.roots
+        m = ColumnDataSource(data=dict(a=[10,11], b=[20,21]))
+        d.add_root(m)
+        assert len(d.roots) == 1
+        assert curdoc() is not d
+        events = []
+        curdoc_from_listener = []
+        def listener(event):
+            curdoc_from_listener.append(curdoc())
+            events.append(event)
+        d.on_change(listener)
+        m.patch(dict(a=[(0, 1)], b=[(0,0), (1,1)]))
+        assert events
+        event = events[0]
+        assert isinstance(event, document.ModelChangedEvent)
+        assert isinstance(event.hint, document.ColumnsPatchedEvent)
+        assert event.document == d
+        assert event.model == m
+        assert event.hint.column_source == m
+        assert event.hint.patches == dict(a=[(0, 1)], b=[(0,0), (1,1)])
+        assert event.attr == 'data'
+        # old == new because stream events update in-place
+        assert event.old == dict(a=[1, 11], b=[0, 1])
+        assert event.new == dict(a=[1, 11], b=[0, 1])
+        assert len(curdoc_from_listener) == 1
+        assert curdoc_from_listener[0] is d
+
+
     def test_change_notification_removal(self):
         d = document.Document()
         assert not d.roots
@@ -447,6 +477,27 @@ class TestDocument(unittest.TestCase):
         assert isinstance(events[0], document.SessionCallbackAdded)
         assert isinstance(events[1], document.SessionCallbackRemoved)
 
+    def test_add_partial_callback(self):
+        from functools import partial
+        d = document.Document()
+
+        events = []
+        def listener(event):
+            events.append(event)
+        d.on_change(listener)
+
+        assert len(d.session_callbacks) == 0
+        assert not events
+
+        def _cb(): pass
+        cb = partial(_cb)
+
+        callback = d.add_timeout_callback(cb, 1)
+        assert len(d.session_callbacks) == len(events) == 1
+        assert isinstance(events[0], document.SessionCallbackAdded)
+        assert callback == d.session_callbacks[0] == events[0].callback
+        assert callback.timeout == 1
+
     def test_add_remove_next_tick_callback(self):
         d = document.Document()
 
