@@ -54,7 +54,8 @@ p.axis.major_label_standoff = 0
 p.xaxis.major_label_orientation = np.pi/3
 
 p.rect('xname', 'yname', 0.9, 0.9, source=source,
-       color='colors', alpha='alphas', line_color=None)
+       color='colors', alpha='alphas', line_color=None,
+       hover_line_color='black', hover_color='colors')
 
 p.select_one(HoverTool).tooltips = [
     ('names', '@yname, @xname'),
